@@ -15,12 +15,9 @@ our @EXPORT_OK = (@DSL, @FUNC, @MSN);
 our %EXPORT_TAGS
   = (all => \@EXPORT_OK, dsl => \@DSL, mdn => \@MSN, func => \@FUNC);
 
-our $VERSION = '0.0159';    # VERSION
+our $VERSION = '0.0160';    # VERSION
 
-sub spy {
-  my %args = @_ == 1 ? (origin => shift) : (@_);
-  Evo::Spy->new(%args);
-}
+sub spy : prototype(;&) { Evo::Spy->new(@_); }
 
 sub _manager             { Evo::Manager->singleton }
 sub asap : prototype(&@) { _manager->asap(@_) }
@@ -36,7 +33,7 @@ sub mdn_subscribe                           { _mdn->subscribe(@_); }
 sub mdn_unsubscribe                         { _mdn->unsubscribe(@_); }
 sub mdn_unsubscribe_from_all : prototype($) { _mdn->unsubscribe_from_all(@_); }
 
-sub guard : prototype(@) { Evo::Guard->new(@_) }
+sub guard : prototype(&) { Evo::Guard->new(@_) }
 
 1;
 
@@ -54,7 +51,7 @@ Evo - Perl Evo design pattern
 
 =head1 VERSION
 
-version 0.0159
+version 0.0160
 
 =head1 SYNOPSIS
 
