@@ -5,20 +5,10 @@ sub new {
   my $class = shift;
   Carp::croak "You have to save Evo::Guard object to the variable"
     unless defined wantarray;
-  bless {@_}, $class;
+  bless {cb => $_[0]}, $class;
 }
 
-sub DESTROY {
-  my $self = shift;
-
-  if ($self->{error}) {
-    my $onerror = delete $self->{error};
-    my $err     = $@;
-    $err and eval { $onerror->($err); 1 } || Carp::carp $@;
-  }
-
-  (delete $self->{always})->() if $self->{always};
-}
+sub DESTROY { (delete $_[0]->{cb})->($@ ? $@ : ()) if $_[0]->{cb} }
 
 1;
 
@@ -36,7 +26,7 @@ Evo::Guard - A guard
 
 =head1 VERSION
 
-version 0.0159
+version 0.0160
 
 =head1 SYNOPSIS
 
@@ -44,14 +34,15 @@ version 0.0159
   use Evo::Guard;
 
   eval {
-    my $guard = Evo::Guard->new(
-      error  => sub { say "ERROR cleanups" },
-      always => sub { say "Always cleanups" }
-    );
+    my $guard
+      = Evo::Guard->new(sub($err=undef) { say $err ? "$err" : "alive" });
     die "Error";
   };
 
-=head2 Arguments
+  eval {
+    my $guard
+      = Evo::Guard->new(sub($err=undef) { say $err ? "$err" : "alive" });
+  };
 
 =head1 DESCRIPTION
 
@@ -70,17 +61,11 @@ Or it can do both
 Creates a guard object. It will raise an exception if you forget to save it
 in somewhere.
 
-If an error callback will cause an exception (but this is surely a bug in 
-your code), always callback will be executed too
+The first argument will be executed when guard is out of scope.
 
-=head3 error
-
-A callback that will be executed only if an unhandled exception was trown in the
-same scope
-
-=head3 always
-
-This callback will be executed no matter was exception thrown or not
+If there was an exception in scope, the first argument will be passed to the
+cb. If all is ok, no arguments will be passed. So you can check the first
+argument to do some job on errors only
 
 =head1 AUTHOR
 
