@@ -1,6 +1,7 @@
 package Evo::Spy;
 use Evo::Base -base;
 use Hash::Util::FieldHash();
+use Evo::Guard;
 
 Hash::Util::FieldHash::fieldhash my %STORE;
 
@@ -28,12 +29,13 @@ sub _execute($class, $id, @args) {
 
   my $orig = $self->origin or return;
 
+  my $guard = Evo::Guard->new(sub { $_[0] and $call->{exception} = $_[0] });
   return $orig->(@args) if !defined $want;
   return $want ? (@$ret = $orig->(@args)) : ($ret->[0] = $orig->(@args));
 }
 
 sub new {
-  my ($class, %args) = @_;
+  my ($class, $origin) = @_;
   my $all = $class->_all_store;
 
   my $self = bless sub { $all->{(__SUB__)}->{code}->(@_) }, $class;
@@ -41,7 +43,7 @@ sub new {
   my $store = $all->{$self} = {};
   my $id = Hash::Util::FieldHash::id $self;
   $store->{code} = sub { $class->_execute($id, @_) };
-  $store->{origin} = $args{origin} if $args{origin};
+  $store->{origin} = $origin if $origin;
 
   $self;
 
@@ -63,13 +65,13 @@ Evo::Spy - A basic spy function-object
 
 =head1 VERSION
 
-version 0.0159
+version 0.0160
 
 =head1 SYNOPSIS
 
   use Evo::Base -strict;
   use Evo::Spy;
-  my $spy = Evo::Spy->new(origin => sub { say "hello ", shift });
+  my $spy = Evo::Spy->new(sub { say "hello ", shift });
 
   $spy->('foo');
   $spy->code->('bar');
@@ -77,14 +79,12 @@ version 0.0159
   use Data::Dumper;
   say Dumper $spy->calls;
 
-=head1 ATTRIBUTES
+=head1 METHODS
 
 =head2 origin
 
 An original code.
 
-=head1 METHODS
-
 =head2 new
 
 Creates a new spy. If no origin will be passed, spy will still record
