@@ -31,7 +31,7 @@ sub run($self) {
     $self->depart;
   }
 
-  my $guard = Evo::Guard->new(always => sub { $self->cleanup });
+  my $guard = Evo::Guard->new(sub { $self->cleanup });
 
   $self->done && $self->done->($self);
   return;
@@ -59,7 +59,7 @@ sub can_run($self) {
 
 # invoke or cleanup
 sub handle_station($self, $station) {
-  my $guard = Evo::Guard->new(error => sub { $self->cleanup });
+  my $guard = Evo::Guard->new(sub { $_[0] and $self->cleanup });
   $station->($self);
 }
 
@@ -88,7 +88,7 @@ Railway::Train - a running engine
 
 =head1 VERSION
 
-version 0.0159
+version 0.0160
 
 =head1 SYNOPSIS
 
